@@ -7,12 +7,14 @@ namespace APE
 #define APE_FILE_CURRENT 1
 #define APE_FILE_END 2
 
+#pragma pack(push, 1)
+
 class CIO
 {   
 public:
     // construction / destruction
-    CIO() 
-    { 
+    CIO()
+    {
         m_nSeekPosition = 0;
         m_nSeekMethod = APE_FILE_BEGIN;
     }
@@ -43,8 +45,6 @@ public:
 
     // other functions
     virtual int SetEOF() = 0;
-    virtual int SetReadWholeFile() = 0;
-    virtual void SetReadToBuffer() = 0;
     virtual unsigned char * GetBuffer(int * pnBufferBytes) = 0;
 
     // attributes
@@ -60,4 +60,6 @@ protected:
 
 CIO * CreateCIO();
 
+#pragma pack(pop)
+
 }
